@@ -198,7 +198,8 @@ structure(list(N = structure(list(Sex = c("Unisex", "Unisex",
     1, 0.999999, 0.999998, 0.999996, 0.999994, 0.999991, 0, 0, 
     0, 1, 1, 1, 1, 1, 1, 1)), .Names = c("Series", "Sex", "Age", 
     "P"), row.names = c(NA, -30L), class = "data.frame"), Dev = structure(list(
-        Initial = structure(c(-0.276004, -0.133551, -0.08248, 
+        sigmaR = structure(c(0.5, 1), .Names = c("Initial", "Annual"
+        )), Initial = structure(c(-0.276004, -0.133551, -0.08248, 
         0.0879693, -0.161992, 0.19093, 0.323306, 0.082165), .Names = c("2", 
         "3", "4", "5", "6", "7", "8", "9")), Annual = structure(c(0.904468, 
         0.0370796, 0.544025, 0.98496, -0.145333, 0.411873, 0.501718, 
@@ -211,23 +212,23 @@ structure(list(N = structure(list(Sex = c("Unisex", "Unisex",
         "1979", "1980", "1981", "1982", "1983", "1984", "1985", 
         "1986", "1987", "1988", "1989", "1990", "1991", "1992", 
         "1993", "1994", "1995", "1996", "1997", "1998", "1999", 
-        "2000", "2001", "2002", "2003"))), .Names = c("Initial", 
-    "Annual")), Survey = structure(list(Series = c(1L, 1L, 1L, 
+        "2000", "2001", "2002", "2003"))), .Names = c("sigmaR", 
+    "Initial", "Annual")), Survey = structure(list(Series = c(1L, 
     1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
     1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
-    1L), Year = 1971:2004, Obs = c(NA, NA, NA, NA, NA, NA, NA, 
-    NA, NA, NA, NA, NA, NA, NA, 548.4, 402.2, 493.1, 561.3, 522, 
-    307, 291.9, 203.8, 220.3, 177.8, 224.2, 325.9, 347, 422.6, 
-    282.2, 251.9, 236.1, 310, 344.5, NA), CV = c(NA, NA, NA, 
-    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 0.2, 0.2, 0.2, 
+    1L, 1L, 1L), Year = 1971:2004, Obs = c(NA, NA, NA, NA, NA, 
+    NA, NA, NA, NA, NA, NA, NA, NA, NA, 548.4, 402.2, 493.1, 
+    561.3, 522, 307, 291.9, 203.8, 220.3, 177.8, 224.2, 325.9, 
+    347, 422.6, 282.2, 251.9, 236.1, 310, 344.5, NA), CV = c(NA, 
+    NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 0.2, 
     0.2, 0.2, 0.2, 0.2, 0.2, 0.2, 0.2, 0.2, 0.2, 0.2, 0.2, 0.2, 
-    0.2, 0.2, 0.2, 0.2, NA), Fit = c(509.758, 436.334, 375.37, 
-    376.073, 395.967, 482.794, 535.93, 578.928, 636.372, 638.789, 
-    519.153, 410.725, 364.678, 378.4, 384.105, 419.75, 464.846, 
-    459.498, 424.87, 346.746, 285.949, 252.182, 259.693, 237.64, 
-    256.392, 313.859, 329.732, 322.584, 288.12, 263.397, 292.159, 
-    298.522, 342.267, 348.371)), .Names = c("Series", "Year", 
-    "Obs", "CV", "Fit"), row.names = c(NA, -34L), class = "data.frame"), 
+    0.2, 0.2, 0.2, 0.2, 0.2, 0.2, NA), Fit = c(509.758, 436.334, 
+    375.37, 376.073, 395.967, 482.794, 535.93, 578.928, 636.372, 
+    638.789, 519.153, 410.725, 364.678, 378.4, 384.105, 419.75, 
+    464.846, 459.498, 424.87, 346.746, 285.949, 252.182, 259.693, 
+    237.64, 256.392, 313.859, 329.732, 322.584, 288.12, 263.397, 
+    292.159, 298.522, 342.267, 348.371)), .Names = c("Series", 
+    "Year", "Obs", "CV", "Fit"), row.names = c(NA, -34L), class = "data.frame"), 
     CAc = structure(list(Series = c(1L, 1L, 1L, 1L, 1L, 1L, 1L, 
     1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
     1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
@@ -664,4 +665,4 @@ structure(list(N = structure(list(Sex = c("Unisex", "Unisex",
         0.0118643)), .Names = c("Series", "Year", "SS", "Sex", 
     "Age", "Obs", "Fit"), row.names = c(NA, -190L), class = "data.frame")), .Names = c("N", 
 "B", "Sel", "Dev", "Survey", "CAc", "CAs"), call = quote(importCol(res.file = "c:/scape/example/cod.res", 
-    Dev = T, Survey = T, CAc = T, CAs = T)), scape.version = "1.1-5", info = "", class = "scape")
+    Dev = TRUE, Survey = TRUE, CAc = TRUE, CAs = TRUE)), scape.version = "2.0-0", info = "", class = "scape")
