@@ -163,20 +163,21 @@ structure(list(N = structure(list(Sex = c("Unisex", "Unisex",
     0.999989, 0.999985, 0, 0.0500001084745763, 0.600000739281345, 
     0.950000460358527, 1, 1, 1, 1, 1, 1, 1)), .Names = c("Series", 
     "Sex", "Age", "P"), row.names = c(NA, -33L), class = "data.frame"), 
-    Dev = structure(list(Initial = structure(c(-0.615429, -0.400785, 
-    0.876576, 0.00762806, -0.221926, 0.120723, 0.723673, -0.115298, 
-    0.225449), .Names = c("2", "3", "4", "5", "6", "7", "8", 
-    "9", "10")), Annual = structure(c(-0.600611, 0.719962, 0.815184, 
-    -0.637111, -2.23805, -0.339889, -0.526867, -0.556781, 0.260493, 
-    -0.548288, 0.45809, -2.22976, -0.149204, 2.48759, 0.93586, 
-    0.0955285, -0.987471, 1.09206, 0.647962, -0.415831, 0.812267, 
-    -0.122915, 0.457657, 0.00141056), .Names = c("1979", "1980", 
-    "1981", "1982", "1983", "1984", "1985", "1986", "1987", "1988", 
-    "1989", "1990", "1991", "1992", "1993", "1994", "1995", "1996", 
-    "1997", "1998", "1999", "2000", "2001", "2002"))), .Names = c("Initial", 
-    "Annual")), Survey = structure(list(Series = c(1L, 1L, 1L, 
+    Dev = structure(list(sigmaR = structure(c(1, 1), .Names = c("Initial", 
+    "Annual")), Initial = structure(c(-0.615429, -0.400785, 0.876576, 
+    0.00762806, -0.221926, 0.120723, 0.723673, -0.115298, 0.225449
+    ), .Names = c("2", "3", "4", "5", "6", "7", "8", "9", "10"
+    )), Annual = structure(c(-0.600611, 0.719962, 0.815184, -0.637111, 
+    -2.23805, -0.339889, -0.526867, -0.556781, 0.260493, -0.548288, 
+    0.45809, -2.22976, -0.149204, 2.48759, 0.93586, 0.0955285, 
+    -0.987471, 1.09206, 0.647962, -0.415831, 0.812267, -0.122915, 
+    0.457657, 0.00141056), .Names = c("1979", "1980", "1981", 
+    "1982", "1983", "1984", "1985", "1986", "1987", "1988", "1989", 
+    "1990", "1991", "1992", "1993", "1994", "1995", "1996", "1997", 
+    "1998", "1999", "2000", "2001", "2002"))), .Names = c("sigmaR", 
+    "Initial", "Annual")), Survey = structure(list(Series = c(1L, 
     1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 
-    1L, 1L, 1L, 1L, 1L, 1L, 1L), Year = 1979:2003, Obs = c(NA, 
+    1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L, 1L), Year = 1979:2003, Obs = c(NA, 
     NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 24033, 
     28841, 130535, NA, NA, 167668, NA, 135612, NA, 152799, NA
     ), CV = c(NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 
@@ -396,5 +397,5 @@ structure(list(N = structure(list(Sex = c("Unisex", "Unisex",
         0.0115264, 0.023058, 0.0405382, 0.158628)), .Names = c("Series", 
     "Year", "SS", "Sex", "Age", "Obs", "Fit"), row.names = c(NA, 
     -253L), class = "data.frame")), .Names = c("N", "B", "Sel", 
-"Dev", "Survey", "CAc"), call = quote(importCol(res.file = "c:/scape/example/sbw.res", 
-    Dev = T, Survey = T, CAc = T)), scape.version = "1.1-5", info = "", class = "scape")
+"Dev", "Survey", "CAc"), call = quote(importCol(res.file = "c:/~/scape/example/sbw.res", 
+    Dev = TRUE, Survey = TRUE, CAc = TRUE)), scape.version = "2.0-0", info = "", class = "scape")
